intelmq.bots.experts.filter package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.filter package

## Submodules

## intelmq.bots.experts.filter.expert module

intelmq.bots.experts.filter.expert.BOT

  alias of `intelmq.bots.experts.filter.expert.FilterExpertBot`

class intelmq.bots.experts.filter.expert.FilterExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Filter events, supports named paths for splitting the message flow

  doFilter(event, key, condition)
  equalsFilter(event, key, value)
  filter_action: str = None
  filter_key: str = None
  filter_regex: str = None
  filter_value: str = None
  init()
  not_after = None
  not_before = None
  parse_timeattr(time_attr)

    Parses relative or absolute time specification, decides how to parse by checking if the string contains any timespan identifier.

    See also https://github.com/certtools/intelmq/issues/1523 dateutil.parser.parse detects strings like 10 hours as absolute time.

  process()
  regexSearchFilter(event, key)

## Module contents